#!/usr/bin/python3 -tt

import pymetar
import sys
import os

if __name__ == "__main__":
    if len(sys.argv) > 1:
        repdir=sys.argv[1]
    else:
        repdir=("reports")

    if len(sys.argv) > 2:
        reports = sys.argv[2:]
    else:
        reports = os.listdir(repdir)
    reports.sort()
    count=0
    rf=pymetar.ReportFetcher()
    for reportfile in reports:

        station = reportfile[:-4]
        sys.stdout.write("%s " % (station))
        sys.stdout.flush()

        fd = open("%s/%s" % (repdir,reportfile))
        try:
            report = fd.read().encode()
        except UnicodeDecodeError:
            continue
        fd.close()

        repo = rf.MakeReport(station, report)
        
        rp = pymetar.ReportParser()
        pr = rp.ParseReport(repo)
        
        a=pr.getPixmap()
        b=pr.getCloudinfo()
        c=pr.getConditions()

        print(a, b, c)

        count += 1

    sys.stderr.write("%s station report pixmaps check out ok\n" % (count))





#!/usr/bin/python -tt
# -*- coding: iso-8859-15 -*-

__version__ = "2.1"

import pymetar
import sys

print("pymet v%s using pymetar lib v%s" % (__version__, pymetar.__version__))

if len(sys.argv) < 2:
    station = "NZCM"
else:
    station = sys.argv[1]

rf = pymetar.ReportFetcher(station)
rep = rf.FetchReport()
rp = pymetar.ReportParser()
pr = rp.ParseReport(rep.decode())

print("--------- Full report ---------")
print(pr.fullreport)
print("------- End full report -------")

print("-------- Parsed Values --------")
for k in list(pr.__dict__.keys()):
    if k != "fullreport":
        print("%s: %s" % (k, pr.__dict__[k]))
print("------ End Parsed Values ------")

print("----- Report getFunctions -----")
print("getTemperatureCelsius(): %s" % (pr.getTemperatureCelsius()))
print("getTemperatureFahrenheit(): %s" % (pr.getTemperatureFahrenheit()))
print("getDewPointCelsius(): %s" % (pr.getDewPointCelsius()))
print("getDewPointFahrenheit(): %s" % (pr.getDewPointFahrenheit()))
print("getWindSpeed(): %s" % (pr.getWindSpeed()))
print("getWindSpeedMilesPerHour(): %s" % (pr.getWindSpeedMilesPerHour()))
print("getWindDirection(): %s" % (pr.getWindDirection()))
print("getWindCompass(): %s" % (pr.getWindCompass()))
print("getVisibilityKilometers(): %s" % (pr.getVisibilityKilometers()))
print("getVisibilityMiles(): %s" % (pr.getVisibilityMiles()))
print("getHumidity(): %s" % (pr.getHumidity()))
print("getPressure(): %s" % (pr.getPressure()))
print("getRawMetarCode(): %s" % (pr.getRawMetarCode()))
print("getWeather(): %s" % (pr.getWeather()))
print("getSkyConditions(): %s" % (pr.getSkyConditions()))
print("getStationName(): %s" % (pr.getStationName()))
print("getStationCity(): %s" % (pr.getStationCity()))
print("getStationCountry(): %s" % (pr.getStationCountry()))
print("getCycle(): %s" % (pr.getCycle()))
print("getStationPosition(): %s" % (repr(pr.getStationPosition())))
print("getStationPositionFloat(): %s" % (repr(pr.getStationPositionFloat())))
print("getStationLatitude(): %s" % (pr.getStationLatitude()))
print("getStationLatitudeFloat(): %s" % (pr.getStationLatitudeFloat()))
print("getStationLongitude(): %s" % (pr.getStationLongitude()))
print("getStationLongitudeFloat(): %s" % (pr.getStationLongitudeFloat()))
print("getStationAltitude(): %s" % (pr.getStationAltitude()))
print("getReportURL(): %s" % (pr.getReportURL()))
print("getTime(): %s" % (pr.getTime()))
print("getISOTime(): %s" % (pr.getISOTime()))
print("getPixmap(): %s" % (pr.getPixmap()))
print("getCloudtype(): %s" % (pr.getCloudtype()))
print("getWindchill(): %s" % (pr.getWindchill()))
print("getWindchillF(): %s" % (pr.getWindchillF()))
print("getCloudinfo(): %s" % (repr(pr.getCloudinfo())))
print("getConditions(): %s" % (repr(pr.getConditions())))

print("--- End Report getFunctions ---")



#!/usr/bin/python3 -tt

import pymetar
import sys
import os

if __name__ == "__main__":
    if len(sys.argv) > 1:
        repdir=sys.argv[1]
    else:
        repdir=("reports")

    if len(sys.argv) > 2:
        reports = sys.argv[2:]
    else:
        reports = os.listdir(repdir)

    reports.sort()
    count=0
    rf=pymetar.ReportFetcher()

    for reportfile in reports:
        station = reportfile[:-4]
        sys.stdout.write("%s " % (station))
        sys.stdout.flush()

        fd = open("%s/%s" % (repdir, reportfile))
        try:
            report = fd.read().encode()
        except UnicodeDecodeError:
            continue
        fd.close()

        repo = rf.MakeReport(station, report)
        
        rp = pymetar.ReportParser()
        pr = rp.ParseReport(repo)
        
        a=pr.getFullReport()
        a=pr.getTemperatureCelsius()
        a=pr.getTemperatureFahrenheit()
        a=pr.getDewPointCelsius()
        a=pr.getDewPointFahrenheit()
        a=pr.getWindSpeed()
        a=pr.getWindSpeedMilesPerHour()
        a=pr.getWindSpeedBeaufort()
        a=pr.getWindDirection()
        a=pr.getWindCompass()
        a=pr.getVisibilityKilometers()
        a=pr.getVisibilityMiles()
        a=pr.getHumidity()
        a=pr.getPressure()
        a=pr.getPressuremmHg()
        a=pr.getRawMetarCode()
        a=pr.getWeather()
        a=pr.getSkyConditions()
        a=pr.getStationName()
        a=pr.getStationCity()
        a=pr.getStationCountry()
        a=pr.getCycle()
        a=pr.getStationPosition()
        a=pr.getStationPositionFloat()
        a=pr.getStationLatitude()
        a=pr.getStationLatitudeFloat()
        a=pr.getStationLongitude()
        a=pr.getStationLongitudeFloat()
        a=pr.getStationAltitude()
        a=pr.getReportURL()
        a=pr.getTime()
        a=pr.getISOTime()
        a=pr.getPixmap()
        a=pr.getCloudinfo()
        a=pr.getConditions()
        a=pr.getWindchill()
        a=pr.getWindchillF()

        pr._clearallfields()

        count += 1
    
        sys.stdout.write("...ok\n")

    sys.stderr.write("%s station reports check out ok\n" % (count))





#! /usr/bin/env python3
#
# pymetar
# (c) 2002 Tobias Klausmann
# (c) 2002 Jerome Alet <alet@librelogiciel.com>
# You're welcome to redistribute this software under the
# terms of the GNU General Public Licence version 2.0
# or, at your option, any higher version.
#
# You can read the complete GNU GPL in the file COPYING
# which should come along with this software, or visit
# the Free Software Foundation's WEB site http://www.fsf.org
#
# $Id: $

import pymetar
import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="pymetar",
    version=pymetar.__version__,
    author="Tobias Klausmann",
    author_email="klausman-pymetar@schwarzvogel.de",
    description="Pymetar is a python module and command line tool that fetches and parses METAR reports",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="http://www.schwarzvogel.de/software-pymetar.shtml",
    packages=setuptools.find_packages(),
    py_modules=["pymetar"],
    scripts=["bin/pymetar"],
    data_files=[("share/doc/pymetar-%s" % pymetar.__version__,
                 ['README.md', 'COPYING', 'THANKS']),
                ("share/man/man1", ['pymetar.1'])],
    classifiers=(
    "Programming Language :: Python :: 3",
    "License :: OSI Approved :: GNU General Public License v2 or later (GPLv2+)", 
   "Operating System :: OS Independent",)
)
